@@ -153,175 +153,11 @@ editor_replace_all_cb (GtkhtmlEditor *editor,
 
 /************************* End Spell Dialog Callbacks ************************/
 
-/************************ Begin URI Request Callbacks ************************/
-
-static GtkhtmlEditorRequest *
-editor_request_new (GtkhtmlEditor *editor,
-                    const gchar *uri,
-                    GtkHTMLStream *stream,
-                    GCancellable *cancellable,
-                    GAsyncReadyCallback callback,
-                    gpointer user_data)
-{
-	GSimpleAsyncResult *simple;
-	GtkhtmlEditorRequest *request;
-	GList *list;
-
-	request = g_slice_new (GtkhtmlEditorRequest);
-
-	simple = g_simple_async_result_new (
-		G_OBJECT (editor), callback,
-		user_data, gtkhtml_editor_request_async);
-
-	if (cancellable != NULL)
-		g_object_ref (cancellable);
-
-	/* Try to detect file paths posing as URIs. */
-	if (*uri == '/')
-		request->file = g_file_new_for_path (uri);
-	else
-		request->file = g_file_new_for_uri (uri);
-
-	request->editor = g_object_ref (editor);
-	request->cancellable = cancellable;
-	request->simple = simple;
-	request->input_stream = NULL;
-	request->output_stream = stream;
-
-	list = request->editor->priv->requests;
-	list = g_list_prepend (list, request);
-	request->editor->priv->requests = list;
-
-	return request;
-}
-
-static void
-editor_request_free (GtkhtmlEditorRequest *request)
-{
-	GList *list;
-
-	/* Do not free the GSimpleAsyncResult. */
-
-	list = request->editor->priv->requests;
-	list = g_list_remove (list, request);
-	request->editor->priv->requests = list;
-
-	g_object_unref (request->file);
-	g_object_unref (request->editor);
-
-	if (request->cancellable != NULL)
-		g_object_unref (request->cancellable);
-
-	if (request->input_stream != NULL)
-		g_object_unref (request->input_stream);
-
-	g_slice_free (GtkhtmlEditorRequest, request);
-}
-
-static gboolean
-editor_request_check_for_error (GtkhtmlEditorRequest *request,
-                                GError *error)
-{
-	GtkHTML *html;
-	GtkHTMLStream *stream;
-	GSimpleAsyncResult *simple;
-
-	if (error == NULL)
-		return FALSE;
-
-	stream = request->output_stream;
-	html = gtkhtml_editor_get_html (request->editor);
-	gtk_html_end (html, stream, GTK_HTML_STREAM_ERROR);
-
-	/* Steal the result. */
-	simple = request->simple;
-	request->simple = NULL;
-
-	g_simple_async_result_set_from_error (simple, error);
-	g_simple_async_result_complete (simple);
-	g_error_free (error);
-
-	editor_request_free (request);
-
-	return TRUE;
-}
-
-static void
-editor_request_stream_read_cb (GInputStream *input_stream,
-                               GAsyncResult *result,
-                               GtkhtmlEditorRequest *request)
-{
-	GtkHTML *html;
-	GtkHTMLStream *stream;
-	gssize bytes_read;
-	GError *error = NULL;
-
-	stream = request->output_stream;
-	html = gtkhtml_editor_get_html (request->editor);
-
-	bytes_read = g_input_stream_read_finish (input_stream, result, &error);
-
-	if (editor_request_check_for_error (request, error))
-		return;
-
-	if (bytes_read == 0) {
-		GSimpleAsyncResult *simple;
-
-		/* Steal the result. */
-		simple = request->simple;
-		request->simple = NULL;
-
-		gtk_html_end (html, stream, GTK_HTML_STREAM_OK);
-
-		g_simple_async_result_set_op_res_gboolean (simple, TRUE);
-		g_simple_async_result_complete (simple);
-		editor_request_free (request);
-
-		return;
-	}
-
-	gtk_html_write (html, stream, request->buffer, bytes_read);
-
-	g_input_stream_read_async (
-		request->input_stream, request->buffer,
-		sizeof (request->buffer), G_PRIORITY_DEFAULT,
-		request->cancellable, (GAsyncReadyCallback)
-		editor_request_stream_read_cb, request);
-}
-
-static void
-editor_request_read_cb (GFile *file,
-                        GAsyncResult *result,
-                        GtkhtmlEditorRequest *request)
-{
-	GFileInputStream *input_stream;
-	GError *error = NULL;
-
-	/* Input stream might be NULL, so don't use cast macro. */
-	input_stream = g_file_read_finish (file, result, &error);
-	request->input_stream = (GInputStream *) input_stream;
-
-	if (editor_request_check_for_error (request, error))
-		return;
-
-	g_input_stream_read_async (
-		request->input_stream, request->buffer,
-		sizeof (request->buffer), G_PRIORITY_DEFAULT,
-		request->cancellable, (GAsyncReadyCallback)
-		editor_request_stream_read_cb, request);
-}
-
-/************************* End URI Request Callbacks *************************/
-
 void
 gtkhtml_editor_private_init (GtkhtmlEditor *editor)
 {
 	GtkhtmlEditorPrivate *priv = editor->priv;
 
-	GtkHTML *html;
-	GtkWidget *widget;
-	GtkToolbar *toolbar;
-	GtkToolItem *tool_item;
 	gchar *filename;
 	GError *error = NULL;
 
@@ -356,6 +192,8 @@ gtkhtml_editor_private_init (GtkhtmlEditor *editor)
 	filename = gtkhtml_editor_find_data_file ("gtkhtml-editor-builder.ui");
 
 	priv->builder = gtk_builder_new ();
+	/* To keep translated strings in subclasses */
+	gtk_builder_set_translation_domain (priv->builder, GETTEXT_PACKAGE);
 	if (!gtk_builder_add_from_file (priv->builder, filename, &error)) {
 		g_critical ("Couldn't load builder file: %s\n", error->message);
 		g_clear_error (&error);
@@ -371,6 +209,20 @@ gtkhtml_editor_private_init (GtkhtmlEditor *editor)
 
 	gtk_builder_connect_signals (priv->builder, NULL);
 
+	/* Wait to construct the main window widgets
+	 * until the 'html' property is initialized. */
+}
+
+void
+gtkhtml_editor_private_constructed (GtkhtmlEditor *editor)
+{
+	GtkhtmlEditorPrivate *priv = editor->priv;
+
+	GtkHTML *html;
+	GtkWidget *widget;
+	GtkToolbar *toolbar;
+	GtkToolItem *tool_item;
+
 	/* Construct main window widgets. */
 
 	widget = gtkhtml_editor_get_managed_widget (editor, "/main-menu");
@@ -405,11 +257,8 @@ gtkhtml_editor_private_init (GtkhtmlEditor *editor)
 	priv->scrolled_window = g_object_ref (widget);
 	gtk_widget_show (widget);
 
-	widget = gtk_html_new ();
-	gtk_html_load_empty (GTK_HTML (widget));
-	gtk_html_set_editable (GTK_HTML (widget), TRUE);
+	widget = GTK_WIDGET (gtkhtml_editor_get_html (editor));
 	gtk_container_add (GTK_CONTAINER (priv->scrolled_window), widget);
-	priv->edit_area = g_object_ref (widget);
 	gtk_widget_show (widget);
 
 	/* Add some combo boxes to the "edit" toolbar. */
@@ -633,82 +482,6 @@ gtkhtml_editor_find_data_file (const gchar *basename)
 	return NULL;  /* never gets here */
 }
 
-gint
-gtkhtml_editor_insert_file (GtkhtmlEditor *editor,
-                            const gchar *title,
-                            GCallback response_cb)
-{
-	GtkWidget *dialog;
-	gint response;
-
-	g_return_val_if_fail (GTKHTML_IS_EDITOR (editor), GTK_RESPONSE_CANCEL);
-	g_return_val_if_fail (response_cb != NULL, GTK_RESPONSE_CANCEL);
-
-	dialog = gtk_file_chooser_dialog_new (
-		title, GTK_WINDOW (editor),
-		GTK_FILE_CHOOSER_ACTION_OPEN,
-		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-		GTK_STOCK_OPEN, GTK_RESPONSE_OK,
-		NULL);
-
-	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (dialog), FALSE);
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-
-	g_signal_connect (dialog, "response", response_cb, editor);
-
-	response = gtkhtml_editor_file_chooser_dialog_run (editor, dialog);
-
-	gtk_widget_destroy (dialog);
-
-	return response;
-}
-
-void
-gtkhtml_editor_request_async (GtkhtmlEditor *editor,
-                              const gchar *uri,
-                              GtkHTMLStream *stream,
-                              GCancellable *cancellable,
-                              GAsyncReadyCallback callback,
-                              gpointer user_data)
-{
-	GtkhtmlEditorRequest *request;
-
-	g_return_if_fail (GTKHTML_IS_EDITOR (editor));
-	g_return_if_fail (uri != NULL);
-	g_return_if_fail (stream != NULL);
-	g_return_if_fail (callback != NULL);
-
-	if (cancellable != NULL)
-		g_return_if_fail (G_IS_CANCELLABLE (cancellable));
-
-	request = editor_request_new (
-		editor, uri, stream, cancellable, callback, user_data);
-
-	g_file_read_async (
-		request->file, G_PRIORITY_DEFAULT,
-		request->cancellable, (GAsyncReadyCallback)
-		editor_request_read_cb, request);
-}
-
-gboolean
-gtkhtml_editor_request_finish (GtkhtmlEditor *editor,
-                               GAsyncResult *result,
-                               GError **error)
-{
-	GSimpleAsyncResult *simple;
-	gboolean success;
-
-	g_return_val_if_fail (GTKHTML_IS_EDITOR (editor), FALSE);
-	g_return_val_if_fail (G_IS_SIMPLE_ASYNC_RESULT (result), FALSE);
-
-	simple = G_SIMPLE_ASYNC_RESULT (result);
-	success = g_simple_async_result_get_op_res_gboolean (simple);
-	g_simple_async_result_propagate_error (simple, error);
-	g_object_unref (simple);
-
-	return success;
-}
-
 GFile *
 gtkhtml_editor_run_open_dialog (GtkhtmlEditor *editor,
                                 const gchar *title,
@@ -799,15 +572,11 @@ gtkhtml_editor_spell_check (GtkhtmlEditor *editor,
                             gboolean whole_document)
 {
 	GtkHTML *html;
-	guint position;
-	gboolean inline_spelling;
 	gboolean spelling_errors;
 
 	g_return_if_fail (GTKHTML_IS_EDITOR (editor));
 
 	html = gtkhtml_editor_get_html (editor);
-	position = html->engine->cursor->position;
-	inline_spelling = gtk_html_get_inline_spelling (html);
 
 	if (whole_document) {
 		html_engine_disable_selection (html->engine);
