@@ -25,6 +25,10 @@
 
 #include <glib/gi18n-lib.h>
 
+#ifdef HAVE_XFREE
+#include <X11/XF86keysym.h>
+#endif
+
 /* Custom Widgets */
 #include "gtkhtml-color-combo.h"
 #include "gtkhtml-color-palette.h"
@@ -32,6 +36,7 @@
 #include "gtkhtml-combo-box.h"
 #include "gtkhtml-face-action.h"
 #include "gtkhtml-face-chooser.h"
+#include "gtkhtml-image-chooser-dialog.h"
 #include "gtkhtml-spell-dialog.h"
 
 /* GtkHTML internals */
@@ -68,10 +73,6 @@
 /* Marshalling */
 #include "gtkhtml-editor-marshal.h"
 
-#define GTKHTML_EDITOR_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), GTKHTML_TYPE_EDITOR, GtkhtmlEditorPrivate))
-
 /* Shorthand, requires a variable named "editor". */
 #define ACTION(name)	(GTKHTML_EDITOR_ACTION_##name (editor))
 #define WIDGET(name)	(GTKHTML_EDITOR_WIDGET_##name (editor))
@@ -150,9 +151,6 @@ struct _GtkhtmlEditorPrivate {
 
 	/*** Link Properties State ***/
 
-	HTMLObject *link_object;
-	gint link_start_offset;
-	gint link_end_offset;
 	gboolean link_custom_description;
 
 	/*** Rule Properties State ***/
@@ -202,9 +200,6 @@ void		gtkhtml_editor_private_finalize	(GtkhtmlEditor *editor);
 
 void		gtkhtml_editor_actions_init	(GtkhtmlEditor *editor);
 gchar *		gtkhtml_editor_find_data_file	(const gchar *basename);
-gint		gtkhtml_editor_insert_file	(GtkhtmlEditor *editor,
-						 const gchar *title,
-						 GCallback response_cb);
 GFile *		gtkhtml_editor_run_open_dialog	(GtkhtmlEditor *editor,
 						 const gchar *title,
 						 GtkCallback customize_func,
